[![Documentation Status](https://readthedocs.org/projects/poplar/badge/?version=latest)](https://poplar.readthedocs.io/en/latest/)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![DOI](https://zenodo.org/badge/586973569.svg)](https://zenodo.org/badge/latestdoi/586973569)
# poplar
Augmenting selection bias modelling with machine learning for big speedups.

The methodology behind this package is introduced in [Chapman-Bird et al. (2023)](https://doi.org/10.1093/mnras/stad1397) for the specific case of modelling selection biases in extreme mass ratio inspiral (EMRI) populations. If you use this package in your work, please cite this paper **and** the [code package doi](https://doi.org/10.5281/zenodo.7573034).

Authors:
- **Christian Chapman-Bird**

Contributors:
- Maybe you!
